import psycopg2
import pymysql
import sys


class Connection:
    def __init__(self,**ConnectInfor):
        self.ConnectInfor = ConnectInfor

    # Postgresql
    def ConectPsql(self):
        try:
            conn = psycopg2.connect(
                host=self.ConnectInfor['host'],
                port=self.ConnectInfor['port'],
                dbname=self.ConnectInfor['dbname'],
                user=self.ConnectInfor['user'],
                password=self.ConnectInfor['password']
            )
            print('成功连至数据库')
            return conn
        except:
            print("连接失败")
            print(sys.exc_info())


    # Mysql
    def ConectMysql(self):
        try:
            conn = pymysql.connect(
                host=self.ConnectInfor['host'],
                port=self.ConnectInfor['port'],
                database=self.ConnectInfor['dbname'],
                user=self.ConnectInfor['user'],
                password=self.ConnectInfor['password']
            )
            print('成功连至数据库')
            return conn
        except:
            print("连接失败")
            print(sys.exc_info())



# -*- coding:UTF-8 -*-
#!/usr/bin/env python
from __future__ import print_function
from setuptools import setup

setup(
 name="wbs_connectdb",
 version="0.0.3",
 author="WangBenSen",
 author_email="OTLXmao@126.com",
 license="Apache License",
 url="https://xxxxxxxxx",
 packages=["Connection_Tool"],
 install_requires=["psycopg2-binary <= 2.9.3 ", "pymysql <= 1.0.2"],
 classifiers=[
 "Environment :: Web Environment",
 "Intended Audience :: Developers",
 "Operating System :: OS Independent",
 "Topic :: Text Processing :: Indexing",
 "Topic :: Utilities",
 "Topic :: Internet",
 "Topic :: Software Development :: Libraries :: Python Modules",
 "Programming Language :: Python",
 "Programming Language :: Python :: 3.9"
 ],
)
